# Fundcrunch library

* connect directly to various exchanges and bind they stream into single local socket endpoint
* connector to Fundcrunch.Tech data streaming socket and REST endpoints

## Installation

```bash
$ git clone git@github.com:fundcrunch-tech/fundcrunch_py.git
$ cd fundcrunch_py
```


```bash
$ python3.7 -m venv .venv
$ source .venv/bin/activate
$ python setup.py install
```

```bash
$ cd examples
$ python feeder.py
```

